@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2009-2012 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2009-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-kajongg is free software you can redistribute it and/or modify
+Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation either version 2 of the License, or
 (at your option) any later version.
@@ -18,11 +18,11 @@ along with this program if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
-from PyQt4.QtCore import Qt, QVariant, QAbstractTableModel, QModelIndex, QSize
-from PyQt4.QtGui import QWidget, QLineEdit, QVBoxLayout, QColor, QAbstractItemView
+from qt import Qt, QVariant, QAbstractTableModel, QModelIndex, QSize
+from qt import QWidget, QLineEdit, QVBoxLayout, QColor, QAbstractItemView
 
-from util import m18n, logDebug
-from guiutil import MJTableView
+from log import m18n, logDebug
+from guiutil import MJTableView, decorateWindow
 from statesaver import StateSaver
 from message import ChatMessage
 from common import Debug
@@ -31,7 +31,7 @@ from kde import KApplication
 
 class ChatModel(QAbstractTableModel):
     """a model for the chat view"""
-    def __init__(self, parent = None):
+    def __init__(self, parent=None):
         super(ChatModel, self).__init__(parent)
         self.chatLines = []
 
@@ -110,13 +110,14 @@ class ChatView(MJTableView):
 
 class ChatWindow(QWidget):
     """a widget for showing chat messages"""
-    def __init__(self, table=None, game=None):
+    def __init__(self, scene=None, table=None):
         super(ChatWindow, self).__init__(None)
-        self.table = table or game.client.table
+        self.scene = scene
+        self.table = table or scene.game.client.table
         self.table.chatWindow = self
-        title = m18n('Chat on table %1 at %2', self.table.tableid, self.table.client.connection.url)
         self.setObjectName('chatWindow')
-        self.setWindowTitle(title + ' - kajongg')
+        title = m18n('Chat on table %1 at %2', self.table.tableid, self.table.client.connection.url)
+        decorateWindow(self, title)
         self.messageView = ChatView()
         self.messageView.setModel(ChatModel())
         self.messageView.setFocusPolicy(Qt.NoFocus)
@@ -148,7 +149,8 @@ class ChatWindow(QWidget):
 
     def kill(self):
         """hide and null on table"""
-        print('chat.kill for %s on table %s' % (self, self.table))
+        if Debug.chat:
+            logDebug('chat.kill for %s on table %s' % (self, self.table))
         self.hide()
         self.table.chatWindow = None
 
