@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 
 """
-Copyright (C) 2008-2012 Wolfgang Rohdewald <wolfgang@rohdewald.de>
+Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
-kajongg is free software you can redistribute it and/or modify
+Kajongg is free software you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation either version 2 of the License, or
 (at your option) any later version.
@@ -18,13 +18,13 @@ along with this program if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 """
 
-from PyQt4.QtCore import Qt, QVariant, QAbstractTableModel, QModelIndex
-from PyQt4.QtGui import QLabel, QDialog, \
+from qt import Qt, QVariant, QAbstractTableModel, QModelIndex
+from qt import QLabel, QDialog, \
         QHBoxLayout, QVBoxLayout, QDialogButtonBox
 
-from util import m18n, m18nc
+from log import m18n, m18nc
 from statesaver import StateSaver
-from guiutil import ListComboBox, MJTableView
+from guiutil import ListComboBox, MJTableView, decorateWindow
 from common import Debug
 from modeltest import ModelTest
 
@@ -48,7 +48,7 @@ class DifferModel(QAbstractTableModel):
 
     def data(self, index, role=Qt.DisplayRole):
         """get from model"""
-        if not index.isValid() or not (0 <= index.row() < len(self.diffs)):
+        if not index.isValid() or not 0 <= index.row() < len(self.diffs):
             return QVariant()
         diff = self.diffs[index.row()]
         column = index.column()
@@ -92,7 +92,9 @@ class RulesetDiffer(QDialog):
         for left in leftRulesets:
             for right in rightRulesets[:]:
                 if left == right and left.name == right.name:
-                    rightRulesets.remove(right)
+                    # rightRulesets.remove(right) this is wrong because it removes the
+                    # first ruleset with the same hash
+                    rightRulesets = list(x for x in rightRulesets if id(x) != id(right))
         self.leftRulesets = leftRulesets
         self.rightRulesets = rightRulesets
         self.model = None
@@ -120,7 +122,7 @@ class RulesetDiffer(QDialog):
         layout.addLayout(cmdLayout)
         self.setLayout(layout)
 
-        self.setWindowTitle(m18n("Compare") + ' - Kajongg')
+        decorateWindow(self, m18n("Compare"))
         self.setObjectName('RulesetDiffer')
 
         self.cbRuleset1.currentIndexChanged.connect(self.leftRulesetChanged)
