@@ -1,5 +1,6 @@
-"""Copyright (c) 2007-8 Qtrac Ltd. All rights reserved.
-Copyright (C) 2008-2011 Wolfgang Rohdewald
+"""
+Copyright (c) 2007-2008 Qtrac Ltd <mark@qtrac.eu>
+Copyright (C) 2008-2014 Wolfgang Rohdewald <wolfgang@rohdewald.de>
 
  This program or module is free software: you can redistribute it and/or
  modify it under the terms of the GNU General Public License as published
@@ -11,9 +12,11 @@ Copyright (C) 2008-2011 Wolfgang Rohdewald
  the GNU General Public License for more details.
 """
 
-from PyQt4.QtCore import Qt, QSize, QRect, QEvent
-from PyQt4.QtGui import QStyledItemDelegate, QLabel, QTextDocument, QStyle, QPalette, \
-    QStyleOptionViewItemV4, QApplication
+from qt import usingQt5, Qt, RealQVariant, variantValue, QSize, QRect, QEvent
+from qt import QStyledItemDelegate, QLabel, QTextDocument, QStyle, QPalette, \
+    QStyleOptionViewItem, QApplication
+
+from guiutil import Painter
 
 class RichTextColumnDelegate(QStyledItemDelegate):
     """enables rich text in a view"""
@@ -32,21 +35,21 @@ class RichTextColumnDelegate(QStyledItemDelegate):
         else:
             role = QPalette.AlternateBase if index.row() % 2 else QPalette.Base
         self.label.setBackgroundRole(role)
-        text = index.model().data(index, Qt.DisplayRole).toString()
+        with RealQVariant():
+            text = variantValue(index.model().data(index, Qt.DisplayRole))
         self.label.setText(text)
         self.label.setFixedSize(option.rect.size())
-        painter.save()
-        painter.translate(option.rect.topLeft())
-        self.label.render(painter)
-        painter.restore()
+        with Painter(painter):
+            painter.translate(option.rect.topLeft())
+            self.label.render(painter)
 
     def sizeHint(self, option, index):
         """compute size for the final formatted richtext"""
-        text = index.model().data(index).toString()
+        with RealQVariant():
+            text = variantValue(index.model().data(index))
         self.document.setDefaultFont(option.font)
         self.document.setHtml(text)
-        return QSize(self.document.idealWidth() + 5,
-                     option.fontMetrics.height() )
+        return QSize(self.document.idealWidth() + 5, option.fontMetrics.height())
 
 class RightAlignedCheckboxDelegate(QStyledItemDelegate):
     """as the name says. From
@@ -63,7 +66,7 @@ class RightAlignedCheckboxDelegate(QStyledItemDelegate):
 
     def paint(self, painter, option, index):
         """paint right aligned checkbox"""
-        viewItemOption = QStyleOptionViewItemV4(option)
+        viewItemOption = QStyleOptionViewItem(option)
         if self.cellFilter(index):
             textMargin = self.__textMargin()
             newRect = QStyle.alignedRect(option.direction, Qt.AlignRight,
@@ -77,7 +80,7 @@ class RightAlignedCheckboxDelegate(QStyledItemDelegate):
         """edit right aligned checkbox"""
         flags = model.flags(index)
         # make sure that the item is checkable
-        if (not (flags & Qt.ItemIsUserCheckable) or not (flags & Qt.ItemIsEnabled)):
+        if not flags & Qt.ItemIsUserCheckable or not flags & Qt.ItemIsEnabled:
             return False
         # make sure that we have a check state
         value = index.data(Qt.CheckStateRole)
@@ -98,7 +101,9 @@ class RightAlignedCheckboxDelegate(QStyledItemDelegate):
                 return False
         else:
             return False
-        if value.toInt()[0] == Qt.Checked:
+        if not usingQt5:
+            value = value.toInt()[0]
+        if value == Qt.Checked:
             state = Qt.Unchecked
         else:
             state = Qt.Checked
